Description Usage Arguments Value See Also
View source: R/extract.copula.pars.R
A function for extracting the copula parameters parameterizing the mixture components of a regularized copula-based mixture model from a list of mvdc objects. The copula parameter for each mixture component can be extracted in terms of a correlation matrix or a matrix of angles.
1 | extract_copula_pars(mvdc, as_angles = F)
|
mvdc |
A list of objects of class |
as_angles |
A logical value indicating whether the copula parameter should be returned as a matrix of angles instead of a correlation matrix. |
A list of matrices corresponding to the copula parameter of each mixture component contained in mvdc.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.